
# Poleemploi Connector

> Thanks to the Job Offers API, you can access all the job offers available on the Pôle emploi website at any time and in real time.


🔗 https://www.pole-emploi.fr/

# 🔌 Connector Actions
<p align="center">

| Action | Description |
| ------- | ----------- |
| [**Pull job list**](docs/pull_job_list.md) | Retrieves jobs via the ***Offres d'emploi v2*** API from the Pôle emploi website based on selection criteria set in the and send them to a ***Hrflow.ai Board***. |


</p>